import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { useModel } from '@/store';
import { Loading } from '@antmjs/vantui';
import Auth from '@/components/Auth';
import laySty from './layout.module.less';

export default (props) => {
  const { className, style, roles, showTabBar } = props;

  const { person, user } = useModel('user');

  const classNames = `${laySty['page-wrapper']} ${className}`;

  React.useMemo(() => {
    if (showTabBar) {
      Taro.showTabBar();
    } else {
      Taro.hideTabBar();
    }
  }, [showTabBar]);

  React.useEffect(() => {
    console.log('----------->', person, user);
    if (person && !user) {
      const currentPage = Taro.getCurrentPages().slice().pop();      
      if ('pages/login/index' !== currentPage.route) {
        Taro.navigateTo({
          url: '/pages/login/index',
        })
      }
    }
  }, [person, user]);

  return (
    <View className={classNames} style={style}>
      {
        !person && (
          <View className={laySty.loading}>
            <Loading size="32px" vertical>
              加载中...
            </Loading>
          </View>
        )
      }
      <Auth roles={roles}>
      {props.children}
      </Auth>
    </View>
  )
}
